OPTIONS nocenter nolabel formchar = "|----|+|---+=";
/* Example 1 dataset from Cafri */
proc import datafile="U:\Data\cafri\data3.csv"
     out=data3
     dbms=csv
     replace;
     getnames=yes;
run;

/* change coding of gender to 0/1 (0=m, 1=f) */
DATA data3b; set data3;
genderf = gender - 1;
RUN;

PROC MEANS;
RUN;

/* Mixed model with NO clustering effect */
PROC MIXED data=data3b;
CLASS childid;
MODEL math= year genderf schooltype genderf*year/s;
RANDOM intercept year/sub=childid TYPE=un;
RUN;

/* Mixed model with clustering effect of first school */
PROC MIXED data=data3b;
CLASS childid schoolidhlm ;
MODEL math= year genderf schooltype genderf*year/s;
RANDOM intercept year/sub=childid TYPE=un;
RANDOM intercept /sub=schoolidhlm;
RUN;

/* Acute-Effects CCREM */
PROC MIXED data=data3b;
CLASS childid schoolidccrem ;
MODEL math= year genderf schooltype genderf*year/s;
RANDOM intercept year/sub=childid TYPE=un;
RANDOM intercept /sub=schoolidccrem;
RUN;

/* Acute-Effects CCREM with dynamic group effects - UN */
PROC MIXED data=data3b;
CLASS childid schoolidccrem year2;
MODEL math= year genderf schooltype genderf*year/s;
RANDOM intercept year/sub=childid TYPE=un;
RANDOM year2 /sub=schoolidccrem TYPE=un;
RUN;


/* get correlation matrix of school random effects over time */
data covs;
input t1 t2 t3 t4;
datalines;
17.3132 23.7342 12.0855 8.9422
23.7342 81.4858 53.3208 26.3796
12.0855 53.3208 56.7376 40.8660
8.9422  26.3796 40.8660 45.7929
;
run;

proc iml; 
use covs;
read all var{t1 t2 t3 t4} into cov ; 
print cov;
corr = inv(sqrt(diag(cov)))*cov*inv(sqrt(diag(cov))); 
print corr; 
run;
quit;

